@@ -2,9 +2,13 @@
 
 ;; Copyright (C) 2025 Dr. Sandeep Sadanandan
 
-;; Author: Dr. Sandeep Sadanandan <sands@kotaico.de>
+;; Author: Dr. Sandeep Sadanandan <sillyfellow@whybenormal.org>
 ;; URL: https://github.com/sillyfellow/mu4e-llm
 
+;; This file is NOT part of GNU Emacs.
+
+;; SPDX-License-Identifier: MIT
+
 ;;; Commentary:
 ;; Smart reply drafting with LLM, supporting iterative refinement.
 ;; Output is org-mode syntax compatible with org-msg.
@@ -30,69 +34,11 @@
 (declare-function message-goto-body "message")
 (defvar mu4e-contexts)
 
-;;; --- Prompt Templates ---
-
-(defconst mu4e-llm-draft--persona-descriptions
-  '((professional . "Write in a professional, business-appropriate tone. Be courteous and clear.")
-    (friendly . "Write in a warm, friendly tone while remaining professional. Be personable.")
-    (formal . "Write in a formal, highly professional tone suitable for executive communication.")
-    (concise . "Write as briefly as possible while being clear. Minimize pleasantries."))
-  "Descriptions for each persona style.")
-
-(defconst mu4e-llm-draft--reply-prompt
-  "You are drafting an email reply for %s <%s>.
-
-%s
-
-Based on the email thread below, draft a reply that addresses the key points.
-Use org-mode syntax for formatting (this will be used with org-msg):
-- Use *bold* for emphasis
-- Use /italic/ for subtle emphasis
-- Use bullet lists with - for multiple points
-- Use [[url][text]] for links
-
-Do NOT include email headers (To, From, Subject) - just the body text.
-Do NOT include a signature - that will be added automatically.
-Start with an appropriate greeting.
-
-EMAIL THREAD:
-%s
-
-%s"
-  "Prompt template for generating draft replies.
-Placeholders: user-name, user-email, persona, thread-context, instructions")
-
-(defconst mu4e-llm-draft--refine-prompt
-  "Revise the following email draft according to this instruction: %s
-
-Keep the same basic structure and points, but adjust as requested.
-Use org-mode syntax for formatting.
-Do NOT include email headers or signature.
-
-CURRENT DRAFT:
-%s"
-  "Prompt template for refining drafts.")
-
-(defconst mu4e-llm-draft--compose-prompt
-  "You are composing a new email for %s <%s>.
-
-%s
-
-Write an email based on these instructions: %s
-
-%s
-
-Use org-mode syntax for formatting (this will be used with org-msg):
-- Use *bold* for emphasis
-- Use /italic/ for subtle emphasis
-- Use bullet lists with - for multiple points
-- Use [[url][text]] for links
-
-Do NOT include email headers (To, From, Subject) - just the body text.
-Do NOT include a signature - that will be added automatically.
-Start with an appropriate greeting."
-  "Prompt template for composing new emails.
-Placeholders: user-name, user-email, persona, instructions, recipient-context")
+;; Variables from mu4e-llm-config (suppress byte-compile warnings)
+(defvar mu4e-llm-draft-persona-descriptions)
+(defvar mu4e-llm-draft-reply-prompt)
+(defvar mu4e-llm-draft-refine-prompt)
+(defvar mu4e-llm-draft-compose-prompt)
 
 ;;; --- Context Matching ---
 
@@ -283,12 +229,12 @@ Returns the context object, or nil if no match found."
          (user-name (car identity))
          (user-email (cdr identity))
          (persona-desc (cdr (assq mu4e-llm-draft-persona
-                                  mu4e-llm-draft--persona-descriptions)))
+                                  mu4e-llm-draft-persona-descriptions)))
          (context (mu4e-llm-thread-to-prompt-context thread))
          (extra-instructions (if instructions
                                  (format "\nAdditional instructions: %s" instructions)
                                ""))
-         (prompt (format mu4e-llm-draft--reply-prompt
+         (prompt (format mu4e-llm-draft-reply-prompt
                          user-name user-email
                          persona-desc
                          context
@@ -333,11 +279,11 @@ Optional RECIPIENT and SUBJECT provide context."
          (user-name (car identity))
          (user-email (cdr identity))
          (persona-desc (cdr (assq mu4e-llm-draft-persona
-                                  mu4e-llm-draft--persona-descriptions)))
+                                  mu4e-llm-draft-persona-descriptions)))
          (recipient-context (if recipient
                                 (format "The recipient is: %s" recipient)
                               ""))
-         (prompt (format mu4e-llm-draft--compose-prompt
+         (prompt (format mu4e-llm-draft-compose-prompt
                          user-name user-email
                          persona-desc
                          instructions
@@ -394,7 +340,7 @@ Prompts for recipient and subject, then generates the email body."
   "Refine current draft with INSTRUCTION."
   (let* ((current-draft (mu4e-llm-draft--get-draft-text))
          (buf (current-buffer))
-         (prompt (format mu4e-llm-draft--refine-prompt
+         (prompt (format mu4e-llm-draft-refine-prompt
                          instruction
                          current-draft)))
     ;; Abort previous worker if any
